@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "gt" "3.2.1"
+(define-package "gt" "20250727.230"
   "Translation framework, configurable and scalable."
   '((emacs "28.1")
     (pdd   "0.2.3"))
